summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--kconfiglib.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/kconfiglib.py b/kconfiglib.py
index 405d5c2..59869e3 100644
--- a/kconfiglib.py
+++ b/kconfiglib.py
@@ -2643,7 +2643,7 @@ class Symbol(object):
Equal in effect to assigning the value to the symbol within a .config
file. For bool and tristate symbols, use the 'assignable' attribute to
check which values can currently be assigned. Setting values outside
- 'assignable' will cause Symbol.user_str/tri_value to differ from
+ 'assignable' will cause Symbol.user_value to differ from
Symbol.str/tri_value (be truncated down or up).
Setting a choice symbol to 2 (y) only updates Choice.user_selection on
@@ -2661,7 +2661,7 @@ class Symbol(object):
pass a string.
Values that are invalid for the type (such as "foo" or 1 (m) for a
BOOL) are ignored and won't be stored in Symbol.user_str/tri_value.
Kconfiglib will print a warning by default for invalid assignments,
and set_value() will return False.
@@ -2661,7 +2661,7 @@ class Symbol(object):
pass a string.
Values that are invalid for the type (such as "foo" or 1 (m) for a
- BOOL) are ignored and won't be stored in Symbol.user_str/tri_value.
+ BOOL) are ignored and won't be stored in Symbol.user_value.
Kconfiglib will print a warning by default for invalid assignments,
and set_value() will return False.